@@ -1,5 +1,4 @@
 import cStringIO
-import datetime
 import json
 import xmlrpclib
 import logging
@@ -12,6 +11,7 @@ from django.test import TransactionTestCase
 from django.test.client import Client
 from django.core.exceptions import ValidationError
 from django_testscenarios.ubertest import TestCase
+from django.utils import timezone
 
 from linaro_django_xmlrpc.models import AuthToken
 
@@ -22,6 +22,8 @@ from lava_scheduler_app.models import (
     Tag,
     TestJob,
     DevicesUnavailableException,
+    DeviceDictionary,
+    _check_exclusivity,
 )
 from lava_scheduler_daemon.dbjobsource import DatabaseJobSource
 import simplejson
@@ -195,11 +197,11 @@ class TestTestJob(TestCaseWithFactory):
         self.assertEqual(None, job.requested_device_type)
 
     def test_from_json_and_user_sets_date_submitted(self):
-        before = datetime.datetime.now()
+        before = timezone.now()
         job = TestJob.from_json_and_user(
             self.factory.make_job_json(),
             self.factory.make_user())
-        after = datetime.datetime.now()
+        after = timezone.now()
         self.assertTrue(before < job.submit_time < after)
 
     def test_from_json_and_user_sets_status_to_SUBMITTED(self):
@@ -317,6 +319,24 @@ class TestTestJob(TestCaseWithFactory):
             ValueError, TestJob.from_json_and_user, '{}',
             self.factory.make_user())
 
+    def test_from_json_rejects_exclusive(self):
+        panda_type = self.factory.ensure_device_type(name='panda')
+        panda_board = self.factory.make_device(device_type=panda_type, hostname='panda01')
+        self.assertFalse(panda_board.is_exclusive)
+        job = TestJob.from_json_and_user(
+            self.factory.make_job_json(device_type='panda'),
+            self.factory.make_user())
+        self.assertEqual(panda_type, job.requested_device_type)
+        device_dict = DeviceDictionary.get(panda_board.hostname)
+        self.assertIsNone(device_dict)
+        device_dict = DeviceDictionary(hostname=panda_board.hostname)
+        device_dict.parameters = {'exclusive': 'True'}
+        device_dict.save()
+        self.assertTrue(panda_board.is_exclusive)
+        self.assertRaises(
+            DevicesUnavailableException, _check_exclusivity, [panda_board], pipeline=False
+        )
+
     def make_job_json_for_stream_name(self, stream_name, **kw):
         return self.factory.make_job_json(
             actions=[
@@ -751,6 +771,31 @@ class TestSchedulerAPI(TestCaseWithFactory):
             TestJob.STATUS_CHOICES[TestJob.CANCELING]
         ])
 
+    def test_cancel_job_user(self):
+        """
+        tests whether the user who canceled the job is reflected properly.
+
+        See: https://bugs.linaro.org/show_bug.cgi?id=650
+        """
+        user = User.objects.create_user('test', 'e@mail.invalid', 'test')
+        user.save()
+        cancel_user = User.objects.create_user('test_cancel',
+                                               'cancel@mail.invalid',
+                                               'test_cancel')
+        cancel_user.save()
+        job = self.factory.make_testjob(submitter=user)
+        job.description = "sample job"
+        job.save()
+        job.cancel(user=cancel_user)
+        job = TestJob.objects.get(pk=job.pk)
+        self.assertIn(TestJob.STATUS_CHOICES[job.status], [
+            TestJob.STATUS_CHOICES[TestJob.CANCELED],
+            TestJob.STATUS_CHOICES[TestJob.CANCELING]
+        ])
+        job = TestJob.objects.get(pk=job.pk)  # reload
+        self.assertEqual(job.failure_comment,
+                         "Canceled by %s" % cancel_user.username)
+
     def test_json_vs_yaml(self):
         """
         Test that invalid JSON gets rejected but valid YAML is accepted as pipeline
