@@ -57,6 +57,9 @@ urlpatterns = patterns(
     url(r'^labhealth/device/(?P<pk>[-_a-zA-Z0-9.]+)$',
         'health_job_list',
         name='lava.scheduler.labhealth.detail'),
+    url(r'^longestjobs$',
+        'longest_jobs',
+        name='lava.scheduler.longest_jobs'),
     url(r'^job/(?P<pk>[0-9]+|[0-9]+.[0-9]+)$',
         'job_detail',
         name='lava.scheduler.job.detail'),
@@ -66,6 +69,9 @@ urlpatterns = patterns(
     url(r'^job/(?P<pk>[0-9]+)/definition/plain$',
         'job_definition_plain',
         name='lava.scheduler.job.definition.plain'),
+    url(r'^job/(?P<pk>[0-9]+)/description$',
+        'job_description_yaml',
+        name='lava.scheduler.job.description.yaml'),
     url(r'^job/(?P<pk>[0-9]+)/multinode_definition$',
         'multinode_job_definition',
         name='lava.scheduler.job.multinode_definition'),
