@@ -32,6 +32,7 @@ from django.utils.safestring import mark_safe
 from django.db import models
 from django.db.models import Q
 from django_kvstore import models as kvmodels
+from django.utils import timezone
 
 from django_tables2 import (
     Column,
@@ -65,6 +66,7 @@ from lava_scheduler_app import utils
 from dashboard_app.models import BundleStream
 
 from lava.utils.lavatable import LavaTable, LavaView
+from lava_results_app.utils import description_data, description_filename
 
 from lava_scheduler_app.template_helper import expand_template
 from lava_scheduler_app.job_templates import (
@@ -93,6 +95,7 @@ from lava_scheduler_app.tables import (
     all_jobs_with_custom_sort,
     IndexJobTable,
     FailedJobTable,
+    LongestJobTable,
     DeviceTable,
     NoDTDeviceTable,
     RecentJobsTable,
@@ -227,7 +230,7 @@ class FailureTableView(JobTableView):
 
         start = self.request.GET.get('start', None)
         if start:
-            now = datetime.datetime.now()
+            now = timezone.now()
             start = now + datetime.timedelta(int(start))
 
             end = self.request.GET.get('end', None)
@@ -245,7 +248,7 @@ class WorkerView(JobTableView):
 
 def health_jobs_in_hr(hr=-24):
     return TestJob.objects.values('actual_device').filter(
-        health_check=True, start_time__gte=(datetime.datetime.now() +
+        health_check=True, start_time__gte=(timezone.now() +
                                             relativedelta(hours=hr))).\
         exclude(status__in=[TestJob.SUBMITTED, TestJob.RUNNING]).distinct()
 
@@ -345,7 +348,7 @@ def index(request):
 
 
 def type_report_data(start_day, end_day, dt, health_check):
-    now = datetime.datetime.now()
+    now = timezone.now()
     start_date = now + datetime.timedelta(start_day)
     end_date = now + datetime.timedelta(end_day)
 
@@ -365,7 +368,7 @@ def type_report_data(start_day, end_day, dt, health_check):
 
 
 def device_report_data(start_day, end_day, device, health_check):
-    now = datetime.datetime.now()
+    now = timezone.now()
     start_date = now + datetime.timedelta(start_day)
     end_date = now + datetime.timedelta(end_day)
 
@@ -384,7 +387,7 @@ def device_report_data(start_day, end_day, device, health_check):
 
 
 def job_report(start_day, end_day, health_check):
-    now = datetime.datetime.now()
+    now = timezone.now()
     start_date = now + datetime.timedelta(start_day)
     end_date = now + datetime.timedelta(end_day)
 
@@ -402,7 +405,7 @@ def job_report(start_day, end_day, health_check):
     }
 
 
-@BreadCrumb("Reports", parent=lava_index)
+@BreadCrumb("Reports", parent=index)
 def reports(request):
     health_day_report = []
     health_week_report = []
@@ -415,9 +418,6 @@ def reports(request):
         health_week_report.append(job_report(week * -7 - 7, week * -7, True))
         job_week_report.append(job_report(week * -7 - 7, week * -7, False))
 
-    long_running = TestJob.objects.filter(status__in=[TestJob.RUNNING,
-                                                      TestJob.CANCELING]).order_by('start_time')[:5]
-
     return render_to_response(
         "lava_scheduler_app/reports.html",
         {
@@ -425,7 +425,6 @@ def reports(request):
             'health_day_report': health_day_report,
             'job_week_report': job_week_report,
             'job_day_report': job_day_report,
-            'long_running': long_running,
             'bread_crumb_trail': BreadCrumbTrail.leading_to(index),
         },
         RequestContext(request))
@@ -674,97 +673,6 @@ class NoDTDeviceView(DeviceTableView):
                                      ).order_by('hostname')
 
 
-def populate_capabilities(device_name):
-    """
-    device capabilities data retrieved from health checks
-    param dt: a device type to check for capabilities.
-    return: dict of capabilities based on the most recent health check.
-    the returned dict contains a full set of empty values if no
-    capabilities could be determined.
-    """
-    capability = {
-        'capabilities_date': None,
-        'processor': None,
-        'models': None,
-        'cores': 0,
-        'emulated': False,
-        'flags': [],
-    }
-    hardware_flags = []
-    hardware_cpu_models = []
-    device = Device.objects.get(hostname=device_name)
-    use_health_job = device.device_type.health_check_job != ""
-    try:
-        health_job = TestJob.objects.filter(
-            actual_device=device,
-            health_check=use_health_job,
-            status=TestJob.COMPLETE).latest('submit_time')
-    except TestJob.DoesNotExist:
-        return capability
-    if not health_job:
-        return capability
-    job = TestJob.objects.filter(id=health_job.id)[0]
-    if not job:
-        return capability
-    bundle = job._results_bundle
-    if not bundle:
-        return capability
-    bundle_json = bundle.get_sanitized_bundle().get_human_readable_json()
-    if not bundle_json:
-        return capability
-    bundle_data = simplejson.loads(bundle_json)
-    if 'hardware_context' not in bundle_data['test_runs'][0]:
-        return capability
-    # ok, we finally have a hardware_context for this device type, populate.
-    devices = bundle_data['test_runs'][0]['hardware_context']['devices']
-    capability['capabilities_date'] = job.end_time
-    for device in devices:
-        # multiple core cpus have multiple device.cpu entries, each with attributes.
-        if device['device_type'] == 'device.cpu':
-            if 'cpu_type' in device['attributes']:
-                model = device['attributes']['cpu_type']
-            if 'cpu type' in device['attributes']:
-                    model = device['attributes']['cpu type']
-            if 'model name' in device['attributes']:
-                model = device['attributes']['model name']
-            if 'cpu_part' in device['attributes']:
-                cpu_part = int(device['attributes']['cpu_part'], 16)
-            elif 'CPU part' in device['attributes']:
-                cpu_part = int(device['attributes']['CPU part'], 16)
-            else:
-                cpu_part = None
-            if model.startswith("ARMv7") and cpu_part:
-                if hex(cpu_part) == hex(0xc05):
-                    model = "%s - %s" % (model, "Cortex A5")
-                if hex(cpu_part) == hex(0xc07):
-                    model = "%s - %s" % (model, "Cortex A7")
-                if hex(cpu_part) == hex(0xc08):
-                    model = "%s - %s" % (model, "Cortex A8")
-                if hex(cpu_part) == hex(0xc09):
-                    model = "%s - %s" % (model, "Cortex A9")
-                if hex(cpu_part) == hex(0xc0f):
-                    model = "%s - %s" % (model, "Cortex A15")
-            hardware_cpu_models.append(model)
-            if 'Features' in device['attributes']:
-                hardware_flags.append(device['attributes']['Features'])
-            elif 'flags' in device['attributes']:
-                hardware_flags.append(device['attributes']['flags'])
-            elif 'cpu flags' in device['attributes']:
-                hardware_flags.append(device['attributes']['cpu flags'])
-            if device['attributes']['cpu_type'].startswith("QEMU"):
-                capability['emulated'] = True
-            capability['cores'] += 1
-        if device['device_type'] == 'device.board':
-            capability['processor'] = device['description']
-    if len(hardware_flags) == 0:
-        hardware_flags.append("None")
-    if len(hardware_cpu_models) == 0:
-        hardware_cpu_models.append("None")
-    capability['models'] = ", ".join(hardware_cpu_models)
-    capability['flags'] = ", ".join(hardware_flags)
-    return capability
-
-
 @BreadCrumb("Device Type {pk}", parent=index, needs=['pk'])
 def device_type_detail(request, pk):
     dt = get_object_or_404(DeviceType, pk=pk)
@@ -775,38 +683,38 @@ def device_type_detail(request, pk):
     daily_complete = TestJob.objects.filter(
         actual_device__in=Device.objects.filter(device_type=dt),
         health_check=True,
-        submit_time__gte=(datetime.datetime.now().date() - datetime.timedelta(days=1)),
-        submit_time__lt=datetime.datetime.now().date(),
+        submit_time__gte=(timezone.now().date() - datetime.timedelta(days=1)),
+        submit_time__lt=timezone.now().date(),
         status=TestJob.COMPLETE).count()
     daily_failed = TestJob.objects.filter(
         actual_device__in=Device.objects.filter(device_type=dt),
         health_check=True,
-        submit_time__gte=(datetime.datetime.now().date() - datetime.timedelta(days=1)),
-        submit_time__lt=datetime.datetime.now().date(),
+        submit_time__gte=(timezone.now().date() - datetime.timedelta(days=1)),
+        submit_time__lt=timezone.now().date(),
         status=TestJob.INCOMPLETE).count()
     weekly_complete = TestJob.objects.filter(
         actual_device__in=Device.objects.filter(device_type=dt),
         health_check=True,
-        submit_time__gte=(datetime.datetime.now().date() - datetime.timedelta(days=7)),
-        submit_time__lt=datetime.datetime.now().date(),
+        submit_time__gte=(timezone.now().date() - datetime.timedelta(days=7)),
+        submit_time__lt=timezone.now().date(),
         status=TestJob.COMPLETE).count()
     weekly_failed = TestJob.objects.filter(
         actual_device__in=Device.objects.filter(device_type=dt),
         health_check=True,
-        submit_time__gte=(datetime.datetime.now().date() - datetime.timedelta(days=7)),
-        submit_time__lt=datetime.datetime.now().date(),
+        submit_time__gte=(timezone.now().date() - datetime.timedelta(days=7)),
+        submit_time__lt=timezone.now().date(),
         status=TestJob.INCOMPLETE).count()
     monthly_complete = TestJob.objects.filter(
         actual_device__in=Device.objects.filter(device_type=dt),
         health_check=True,
-        submit_time__gte=(datetime.datetime.now().date() - datetime.timedelta(days=30)),
-        submit_time__lt=datetime.datetime.now().date(),
+        submit_time__gte=(timezone.now().date() - datetime.timedelta(days=30)),
+        submit_time__lt=timezone.now().date(),
         status=TestJob.COMPLETE).count()
     monthly_failed = TestJob.objects.filter(
         actual_device__in=Device.objects.filter(device_type=dt),
         health_check=True,
-        submit_time__gte=(datetime.datetime.now().date() - datetime.timedelta(days=30)),
-        submit_time__lt=datetime.datetime.now().date(),
+        submit_time__gte=(timezone.now().date() - datetime.timedelta(days=30)),
+        submit_time__lt=timezone.now().date(),
         status=TestJob.INCOMPLETE).count()
     health_summary_data = [{
         "Duration": "24hours",
@@ -863,10 +771,29 @@ def device_type_detail(request, pk):
     discrete_data = no_dt_ptable.prepare_discrete_data(no_dt_data)
     discrete_data.update(dt_jobs_ptable.prepare_discrete_data(dt_jobs_data))
 
+    if dt.cores.all():
+        core_string = "%s x %s" % (
+            dt.core_count if dt.core_count else 1,
+            ','.join([core.name for core in dt.cores.all().order_by('name')]))
+    else:
+        core_string = ''
+
+    processor_name = dt.processor if dt.processor else ''
+    architecture_name = dt.architecture if dt.architecture else ''
+    bits_width = dt.bits.width if dt.bits else ''
+    cpu_name = dt.cpu_model if dt.cpu_model else ''
+    desc = dt.description if dt.description else ''
+
     return render_to_response(
         "lava_scheduler_app/device_type.html",
         {
             'device_type': dt,
+            'arch_version': architecture_name,
+            'processor': processor_name,
+            'arch_bits': bits_width,
+            'cores': core_string,
+            'cpu_model': cpu_name,
+            'description': desc,
             'search_data': search_data,
             "discrete_data": discrete_data,
             'terms_data': terms_data,
@@ -1026,6 +953,18 @@ class MyJobsView(JobTableView):
         return jobs.order_by('-submit_time')
 
 
+class LongestJobsView(JobTableView):
+
+    def get_queryset(self):
+        jobs = TestJob.objects.select_related("actual_device", "requested_device",
+                                              "requested_device_type", "group")\
+            .extra(select={'device_sort': 'coalesce(actual_device_id, '
+                                          'requested_device_id, requested_device_type_id)',
+                           'duration_sort': 'end_time - start_time'}).all()\
+            .filter(status__in=[TestJob.RUNNING, TestJob.CANCELING])
+        return jobs.order_by('-start_time')
+
+
 class FavoriteJobsView(JobTableView):
 
     def get_queryset(self):
@@ -1310,6 +1249,13 @@ def job_detail(request, pk):
                                                             test_job=job)
         is_favorite = testjob_user.is_favorite
 
+    description = description_data(job.id)
+    job_data = description.get('job', {})
+    action_list = job_data.get('actions', [])
+    pipeline = description.get('pipeline', {})
+    deploy_list = [item['deploy'] for item in action_list if 'deploy' in item]
+    boot_list = [item['boot'] for item in action_list if 'boot' in item]
+    test_list = [item['test'] for item in action_list if 'test' in item]
     data = {
         'job': job,
         'show_cancel': job.can_cancel(request.user),
@@ -1320,6 +1266,13 @@ def job_detail(request, pk):
         'change_priority': job.can_change_priority(request.user),
         'context_help': BreadCrumbTrail.leading_to(job_detail, pk='detail'),
         'is_favorite': is_favorite,
+        'device_data': description.get('device', {}),
+        'job_data': job_data,
+        'pipeline_data': pipeline,
+        'deploy_list': deploy_list,
+        'boot_list': boot_list,
+        'test_list': test_list,
+        'description_file': description_filename(job.id)
     }
 
     log_file = job.output_file()
@@ -1389,6 +1342,21 @@ def job_definition(request, pk):
         RequestContext(request))
 
 
+def job_description_yaml(request, pk):
+    job = get_restricted_job(request.user, pk)
+    if not job.is_pipeline:
+        raise Http404()
+    filename = description_filename(job.id)
+    if not filename:
+        raise Http404()
+    with open(filename, 'r') as desc:
+        data = desc.read()
+    response = HttpResponse(data, content_type='text/yaml')
+    response['Content-Disposition'] = "attachment; filename=job_description_%d.yaml" % \
+        job.id
+    return response
+
+
 def job_definition_plain(request, pk):
     job = get_restricted_job(request.user, pk)
     response = HttpResponse(job.display_definition, content_type='text/plain')
@@ -1488,6 +1456,28 @@ def myjobs(request):
         RequestContext(request))
 
 
+@BreadCrumb("Longest Running Jobs", parent=reports)
+def longest_jobs(request, username=None):
+
+    data = LongestJobsView(request, model=TestJob, table_class=LongestJobTable)
+    ptable = LongestJobTable(data.get_table_data())
+    RequestConfig(request, paginate={"per_page": ptable.length}).configure(
+        ptable)
+
+    return render_to_response(
+        "lava_scheduler_app/longestjobs.html",
+        {
+            'bread_crumb_trail': BreadCrumbTrail.leading_to(longest_jobs),
+            'longestjobs_table': ptable,
+            "length": ptable.length,
+            "terms_data": ptable.prepare_terms_data(data),
+            "search_data": ptable.prepare_search_data(data),
+            "discrete_data": ptable.prepare_discrete_data(data),
+            "times_data": ptable.prepare_times_data(data),
+        },
+        RequestContext(request))
+
+
 @BreadCrumb("Favorite Jobs", parent=index)
 def favorite_jobs(request, username=None):
 
@@ -2024,9 +2014,6 @@ def device_detail(request, pk):
 
     visible = filter_device_types(request.user)
 
-    #  device capabilities data retrieved from health checks
-    capabilities = populate_capabilities(device.hostname)
-
     return render_to_response(
         "lava_scheduler_app/device.html",
         {
@@ -2041,6 +2028,8 @@ def device_detail(request, pk):
             'show_forcehealthcheck': device.can_admin(request.user) and
             device.status not in [Device.RETIRED] and device.device_type.health_check_job != "",
             'can_admin': device.can_admin(request.user),
+            'exclusive': device.is_exclusive,
+            'pipeline': device.is_pipeline,
             'show_maintenance': device.can_admin(request.user) and
             device.status in [Device.IDLE, Device.RUNNING, Device.RESERVED],
             'edit_description': device.can_admin(request.user),
@@ -2056,12 +2045,6 @@ def device_detail(request, pk):
             'context_help': BreadCrumbTrail.show_help(device_detail, pk="help"),
             'next_device': next_device,
             'previous_device': previous_device,
-            'capabilities_date': capabilities['capabilities_date'],
-            'processor': capabilities['processor'],
-            'models': capabilities['models'],
-            'cores': capabilities['cores'],
-            'emulated': capabilities['emulated'],
-            'flags': capabilities['flags'],
         },
         RequestContext(request))
 
